==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/WorkflowFileAclFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link WorkflowFileAcl}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class WorkflowFileAclFieldAttributes extends AbstractBeanAttributesDefinition{

    /** canInvalidate (Database column: CAN_INVALIDATE) */
    static public AttributeDefinition canInvalidate =
        new AttributeDefinition("canInvalidate")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_FILE_ACL")
                .setDatabaseId("CAN_INVALIDATE")
                .setMandatory(true)
                .setMaxSize(255)
                .setDefaultValue("1")
                .setType(boolean.class);

    /** canUpload (Database column: CAN_UPLOAD) */
    static public AttributeDefinition canUpload =
        new AttributeDefinition("canUpload")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_FILE_ACL")
                .setDatabaseId("CAN_UPLOAD")
                .setMandatory(true)
                .setMaxSize(255)
                .setDefaultValue("1")
                .setType(boolean.class);

    /** canValidate (Database column: CAN_VALIDATE) */
    static public AttributeDefinition canValidate =
        new AttributeDefinition("canValidate")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_FILE_ACL")
                .setDatabaseId("CAN_VALIDATE")
                .setMandatory(true)
                .setMaxSize(255)
                .setDefaultValue("1")
                .setType(boolean.class);

    /** canViewNotValid (Database column: CAN_VIEW_NOT_VALID) */
    static public AttributeDefinition canViewNotValid =
        new AttributeDefinition("canViewNotValid")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_FILE_ACL")
                .setDatabaseId("CAN_VIEW_NOT_VALID")
                .setMandatory(true)
                .setMaxSize(255)
                .setDefaultValue("1")
                .setType(boolean.class);

    /** canViewPrivate (Database column: CAN_VIEW_PRIVATE) */
    static public AttributeDefinition canViewPrivate =
        new AttributeDefinition("canViewPrivate")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_FILE_ACL")
                .setDatabaseId("CAN_VIEW_PRIVATE")
                .setMandatory(true)
                .setMaxSize(255)
                .setDefaultValue("0")
                .setType(boolean.class);

    /** canViewValid (Database column: CAN_VIEW_VALID) */
    static public AttributeDefinition canViewValid =
        new AttributeDefinition("canViewValid")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_FILE_ACL")
                .setDatabaseId("CAN_VIEW_VALID")
                .setMandatory(true)
                .setMaxSize(255)
                .setDefaultValue("1")
                .setType(boolean.class);

    /** fileBundleFile (Database column: FILE_BUNDLE_FILE_ID) */
    static public AttributeDefinition fileBundleFile =
        new AttributeDefinition("fileBundleFile")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_FILE_ACL")
                .setDatabaseId("FILE_BUNDLE_FILE_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.FileBundleFile.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("description")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.FileBundleFile.class);

    /** id (Database column: ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_FILE_ACL")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(Long.class);

    /** workflowState (Database column: STATE_ID) */
    static public AttributeDefinition workflowState =
        new AttributeDefinition("workflowState")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_FILE_ACL")
                .setDatabaseId("STATE_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.WorkflowState.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.WorkflowState.class);

    /** userId (Database column: USER_ID) */
    static public AttributeDefinition userId =
        new AttributeDefinition("userId")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_FILE_ACL")
                .setDatabaseId("USER_ID")
                .setMandatory(true)
                .setMaxSize(1000)
                .setType(String.class);

    /** workflowUserProfile (Database column: USER_PROFILE_ID) */
    static public AttributeDefinition workflowUserProfile =
        new AttributeDefinition("workflowUserProfile")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_FILE_ACL")
                .setDatabaseId("USER_PROFILE_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.WorkflowUserProfile.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.WorkflowUserProfile.class);

    /** workflow (Database column: WORKFLOW_ID) */
    static public AttributeDefinition workflow =
        new AttributeDefinition("workflow")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_FILE_ACL")
                .setDatabaseId("WORKFLOW_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.Workflow.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.Workflow.class);

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(canInvalidate.getName(),canInvalidate);
        map.put(canUpload.getName(),canUpload);
        map.put(canValidate.getName(),canValidate);
        map.put(canViewNotValid.getName(),canViewNotValid);
        map.put(canViewPrivate.getName(),canViewPrivate);
        map.put(canViewValid.getName(),canViewValid);
        map.put(fileBundleFile.getName(),fileBundleFile);
        map.put(id.getName(),id);
        map.put(workflowState.getName(),workflowState);
        map.put(userId.getName(),userId);
        map.put(workflowUserProfile.getName(),workflowUserProfile);
        map.put(workflow.getName(),workflow);

        return map;
    }
}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/WorkflowFileAclFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link WorkflowFileAcl}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class WorkflowFileAclFieldAttributes extends AbstractBeanAttributesDefinition{

    /** canInvalidate (Database column: CAN_INVALIDATE) */
    static public AttributeDefinition canInvalidate =
        new AttributeDefinition("canInvalidate")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_FILE_ACL")
                .setDatabaseId("CAN_INVALIDATE")
                .setMandatory(true)
                .setMaxSize(1)
                .setTreatAsBoolean(true)
                .setBooleanFalseValue("0")
                .setBooleanTrueValue("1")
                .setDefaultValue("1")
                .setLovFixedList(Arrays.asList(new String[]{"1","0"}))
                .setType(boolean.class);

    /** canUpload (Database column: CAN_UPLOAD) */
    static public AttributeDefinition canUpload =
        new AttributeDefinition("canUpload")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_FILE_ACL")
                .setDatabaseId("CAN_UPLOAD")
                .setMandatory(true)
                .setMaxSize(1)
                .setTreatAsBoolean(true)
                .setBooleanFalseValue("0")
                .setBooleanTrueValue("1")
                .setDefaultValue("1")
                .setLovFixedList(Arrays.asList(new String[]{"1","0"}))
                .setType(boolean.class);

    /** canValidate (Database column: CAN_VALIDATE) */
    static public AttributeDefinition canValidate =
        new AttributeDefinition("canValidate")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_FILE_ACL")
                .setDatabaseId("CAN_VALIDATE")
                .setMandatory(true)
                .setMaxSize(1)
                .setTreatAsBoolean(true)
                .setBooleanFalseValue("0")
                .setBooleanTrueValue("1")
                .setDefaultValue("1")
                .setLovFixedList(Arrays.asList(new String[]{"1","0"}))
                .setType(boolean.class);

    /** canViewNotValid (Database column: CAN_VIEW_NOT_VALID) */
    static public AttributeDefinition canViewNotValid =
        new AttributeDefinition("canViewNotValid")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_FILE_ACL")
                .setDatabaseId("CAN_VIEW_NOT_VALID")
                .setMandatory(true)
                .setMaxSize(1)
                .setTreatAsBoolean(true)
                .setBooleanFalseValue("0")
                .setBooleanTrueValue("1")
                .setDefaultValue("1")
                .setLovFixedList(Arrays.asList(new String[]{"1","0"}))
                .setType(boolean.class);

    /** canViewPrivate (Database column: CAN_VIEW_PRIVATE) */
    static public AttributeDefinition canViewPrivate =
        new AttributeDefinition("canViewPrivate")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_FILE_ACL")
                .setDatabaseId("CAN_VIEW_PRIVATE")
                .setMandatory(true)
                .setMaxSize(1)
                .setTreatAsBoolean(true)
                .setBooleanFalseValue("0")
                .setBooleanTrueValue("1")
                .setDefaultValue("0")
                .setLovFixedList(Arrays.asList(new String[]{"1","0"}))
                .setType(boolean.class);

    /** canViewValid (Database column: CAN_VIEW_VALID) */
    static public AttributeDefinition canViewValid =
        new AttributeDefinition("canViewValid")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_FILE_ACL")
                .setDatabaseId("CAN_VIEW_VALID")
                .setMandatory(true)
                .setMaxSize(1)
                .setTreatAsBoolean(true)
                .setBooleanFalseValue("0")
                .setBooleanTrueValue("1")
                .setDefaultValue("1")
                .setLovFixedList(Arrays.asList(new String[]{"1","0"}))
                .setType(boolean.class);

    /** fileBundleFile (Database column: FILE_BUNDLE_FILE_ID) */
    static public AttributeDefinition fileBundleFile =
        new AttributeDefinition("fileBundleFile")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_FILE_ACL")
                .setDatabaseId("FILE_BUNDLE_FILE_ID")
                .setMandatory(true)
                .setMaxSize(22)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.FileBundleFile.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("description")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.FileBundleFile.class);

    /** id (Database column: ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_FILE_ACL")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(22)
                .setType(Long.class);

    /** workflowState (Database column: STATE_ID) */
    static public AttributeDefinition workflowState =
        new AttributeDefinition("workflowState")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_FILE_ACL")
                .setDatabaseId("STATE_ID")
                .setMandatory(false)
                .setMaxSize(22)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.WorkflowState.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.WorkflowState.class);

    /** userId (Database column: USER_ID) */
    static public AttributeDefinition userId =
        new AttributeDefinition("userId")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_FILE_ACL")
                .setDatabaseId("USER_ID")
                .setMandatory(false)
                .setMaxSize(1000)
                .setType(String.class);

    /** workflowUserProfile (Database column: USER_PROFILE_ID) */
    static public AttributeDefinition workflowUserProfile =
        new AttributeDefinition("workflowUserProfile")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_FILE_ACL")
                .setDatabaseId("USER_PROFILE_ID")
                .setMandatory(false)
                .setMaxSize(22)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.WorkflowUserProfile.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.WorkflowUserProfile.class);

    /** workflow (Database column: WORKFLOW_ID) */
    static public AttributeDefinition workflow =
        new AttributeDefinition("workflow")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_FILE_ACL")
                .setDatabaseId("WORKFLOW_ID")
                .setMandatory(true)
                .setMaxSize(22)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.Workflow.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.Workflow.class);

    /**
     * Gets description field.
     *
     * @return the description field
     */
    public static String getDescriptionField()
    {
        return null;
    }

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(canInvalidate.getName(),canInvalidate);
        map.put(canUpload.getName(),canUpload);
        map.put(canValidate.getName(),canValidate);
        map.put(canViewNotValid.getName(),canViewNotValid);
        map.put(canViewPrivate.getName(),canViewPrivate);
        map.put(canViewValid.getName(),canViewValid);
        map.put(fileBundleFile.getName(),fileBundleFile);
        map.put(id.getName(),id);
        map.put(workflowState.getName(),workflowState);
        map.put(userId.getName(),userId);
        map.put(workflowUserProfile.getName(),workflowUserProfile);
        map.put(workflow.getName(),workflow);

        return map;
    }
}
